@@ -20,6 +20,7 @@ import (
 	"github.com/openshift/console-operator/pkg/api"
 	"github.com/openshift/console-operator/pkg/console/controllers/clidownloads"
 	"github.com/openshift/console-operator/pkg/console/controllers/resourcesyncdestination"
+	"github.com/openshift/console-operator/pkg/console/controllers/route"
 	"github.com/openshift/console-operator/pkg/console/operatorclient"
 	"github.com/openshift/library-go/pkg/controller/controllercmd"
 	"github.com/openshift/library-go/pkg/operator/management"
@@ -89,10 +90,6 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		options.FieldSelector = fields.OneTermEqualSelector("metadata.name", api.OAuthClientName).String()
 	}
 
-	tweakListOptionsForRoute := func(options *metav1.ListOptions) {
-		options.FieldSelector = fields.OneTermEqualSelector("metadata.name", api.OpenShiftConsoleRouteName).String()
-	}
-
 	kubeInformersNamespaced := informers.NewSharedInformerFactoryWithOptions(
 		kubeClient,
 		resync,
@@ -120,7 +117,6 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		routesClient,
 		resync,
 		routesinformers.WithNamespace(api.TargetNamespace),
-		routesinformers.WithTweakListOptions(tweakListOptionsForRoute),
 	)
 
 	// oauthclients are not namespaced
@@ -138,6 +134,7 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 	operatorClient := &operatorclient.OperatorClient{
 		Informers: operatorConfigInformers,
 		Client:    operatorConfigClient.OperatorV1(),
+		Context:   ctx,
 	}
 
 	recorder := controllerContext.EventRecorder
@@ -157,6 +154,7 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		configClient.ConfigV1(),
 		configInformers,
 		// operator
+		operatorClient,
 		operatorConfigClient.OperatorV1(),
 		operatorConfigInformers.Operator().V1().Consoles(), // OperatorConfig
 
@@ -178,6 +176,8 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		versionGetter,
 		recorder,
 		resourceSyncer,
+		// context
+		ctx,
 	)
 
 	cliDownloadsController := clidownloads.NewCLIDownloadsSyncController(
@@ -192,6 +192,8 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		routesInformersNamespaced.Route().V1().Routes(),       // Routes
 		// recorder
 		recorder,
+		// context
+		ctx,
 	)
 
 	// ResourceSyncDestinationController contains additional logic for all the
@@ -205,10 +207,13 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		kubeInformersNamespaced.Core().V1().ConfigMaps(),
 		// events
 		recorder,
+		// context
+		ctx,
 	)
 
 	consoleServiceController := service.NewServiceSyncController(
 		// clients
+		operatorClient,
 		operatorConfigClient.OperatorV1().Consoles(), // operator config so we can update status
 		kubeClient.CoreV1(),                          // only needs to interact with the service resource
 		// informers
@@ -219,6 +224,29 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		api.OpenShiftConsoleName,
 		// events
 		recorder,
+		// context
+		ctx,
+	)
+
+	consoleRouteController := route.NewRouteSyncController(
+		// top level config
+		configClient.ConfigV1(),
+		// clients
+		operatorClient,
+		operatorConfigClient.OperatorV1().Consoles(),
+		routesClient.RouteV1(),
+		kubeClient.CoreV1(),
+		kubeClient.CoreV1(),
+		// route
+		operatorConfigInformers.Operator().V1().Consoles(),
+		routesInformersNamespaced.Route().V1().Routes(),
+		// names
+		api.OpenShiftConsoleNamespace,
+		api.OpenShiftConsoleRouteName,
+		// events
+		recorder,
+		// context
+		ctx,
 	)
 
 	versionRecorder := status.NewVersionGetter()
@@ -293,6 +321,7 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 	}
 
 	go consoleServiceController.Run(1, ctx.Done())
+	go consoleRouteController.Run(1, ctx.Done())
 	go resourceSyncDestinationController.Run(1, ctx.Done())
 	go consoleOperator.Run(ctx.Done())
 	go cliDownloadsController.Run(1, ctx.Done())
